@@ -29,6 +29,7 @@ from linodecli.baked.request import (
 from linodecli.baked.response import OpenAPIResponse
 from linodecli.baked.util import unescape_arg_segment
 from linodecli.exit_codes import ExitCodes
+from linodecli.help_formatter import SortingHelpFormatter
 from linodecli.output.output_handler import OutputHandler
 from linodecli.overrides import OUTPUT_OVERRIDES
 
@@ -831,6 +832,7 @@ class OpenAPIOperation:
         #  build an argparse
         parser = argparse.ArgumentParser(
             prog=f"linode-cli {self.command} {self.action}",
+            formatter_class=SortingHelpFormatter,
             description=self.summary,
         )
         for param in self.params:
